# lcapy-gui

This package provides an experimental GUI for Lcapy, lcapy-tk.
Schematics can be created and saved in a number of formats and
symbolic component voltages and currents can be inspected.

From the console it can be run as `lcapy-tk`.

From a python interpreter it can be run using:

    from lcapygui import LcapyTk
    e = LcapyTk()
    e.display()
